BEAMZ is an **electromagnetic simulation and inverse / generative design** package with support for multiple backends. It features a **high-level API** that enables fast prototyping and  design with just a few lines of code, ideal for engineers. For researchers, BEAMZ also exposes low-level functionality, making it a flexible playground for developing and testing novel simulation and optimization methods.


```bash
pip install beamz
```

> **Note**: _BEAMZ is currently in a premature state and not publically advertised. If you're a friend of Quentin Wach, feel free to get a first peek, otherwise, consider this package yet to be released._